@@ -1,3 +1,3 @@
 from wiser.gcloud.services.storage import Storage
 
-__all__ = ['Storage']
\ No newline at end of file
+__all__ = ["Storage"]
