@@ -1,3 +1,3 @@
 from wiser.gcloud.services.ai_platform.ai_platform_service import AIPlatform
 
-__all__ = ['AIPlatform']
\ No newline at end of file
+__all__ = ["AIPlatform"]
